@@ -1080,12 +1080,12 @@ def _datetime_to_com_time(dt_time):
 def prepare_xl_data_element(x):
     if isinstance(x, time_types):
         return _datetime_to_com_time(x)
+    elif np and isinstance(x, (np.floating, float)) and np.isnan(x):
+        return ""
     elif np and isinstance(x, np.number):
         return float(x)
     elif x is None:
         return ""
-    elif np and isinstance(x, float) and np.isnan(x):
-        return ""
     else:
         return x
 
